@@ -305,11 +305,12 @@ class Spec:
                             optObject['format'] = option.format
                             pUISchema[name] = {'ui:field': option.format}
 
-                        enums = option.enum.enums
-                        if enums is not None and len(enums) > 0:
-                            enumNames = option.enum.enumNames
-                            optObject['enum'] = enums
-                            optObject['enumNames'] = enumNames
+                        if option.enum is not None:
+                            enums = option.enum.enums
+                            if enums is not None and len(enums) > 0:
+                                enumNames = option.enum.enumNames
+                                optObject['enum'] = enums
+                                optObject['enumNames'] = enumNames
 
                         name = Spec.lower_first_letter(_option['key'])
 
@@ -419,6 +420,15 @@ class Spec:
             val = fields[key]
             if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.input:
                 inputs.append({'key': key, 'val': val})
+            elif not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and key.lower().startswith('in'):
+                inputs.append({
+                    'key': key,
+                    'val': Variable(
+                        title=Spec.camel_case_to_text(key.lstrip('in')),
+                        type=Spec.get_type(val),
+                        default=val
+                    )
+                })
 
         return inputs
 
@@ -441,6 +451,15 @@ class Spec:
             val = fields[key]
             if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.output:
                 outputs.append({'key': key, 'val': val})
+            elif not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and key.lower().startswith('out'):
+                outputs.append({
+                    'key': key,
+                    'val': Variable(
+                        title=Spec.camel_case_to_text(key.lstrip('out')),
+                        type=Spec.get_type(val),
+                        default=val
+                    )
+                })
 
         return outputs
 
@@ -463,6 +482,15 @@ class Spec:
             val = fields[key]
             if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.option:
                 options.append({'key': key, 'val': val})
+            elif not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and key.lower().startswith('opt'):
+                options.append({
+                    'key': key,
+                    'val': Variable(
+                        title=Spec.camel_case_to_text(key.lstrip('opt')),
+                        type=Spec.get_type(val),
+                        default=val
+                    )
+                })
 
         return options
 
@@ -487,3 +515,24 @@ class Spec:
                 options.append({'key': key, 'val': val})
 
         return options
+
+    @staticmethod
+    def camel_case_to_text(str):
+        words = [[str[0].upper()]]
+
+        for c in str[1:]:
+            if words[-1][-1].islower() and c.isupper():
+                words.append(list(c))
+            else:
+                words[-1].append(c)
+
+        word_arr = [''.join(word) for word in words]
+        return ' '.join(word_arr)
+
+    @staticmethod
+    def get_type(val):
+        if isinstance(val, bool):
+            return "boolean"
+        elif isinstance(val, int) or isinstance(val, float):
+            return "number"
+        return "string"
